qustop.Separable
================

.. currentmodule:: qustop

.. autoclass:: Separable

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Separable.__init__
      ~Separable.dual_problem
      ~Separable.primal_problem
      ~Separable.solve
   
   

   
   
   